@@ -12,7 +12,9 @@ import pytesseract
 from PIL import Image
 import pytz
 import time
-
+from PyPDF2 import PdfWriter, PdfReader, PdfMerger
+from pathlib import Path
+import sys
 
 def df_retainCols(dfdata, collist): #deletes columns in df which are not there in list of columns
     # collist (a list) should contain the list of columns to be retained
@@ -666,3 +668,97 @@ def progress_bar(iteration, total, prefix = '', suffix = '', decimals = 1, lengt
     # Print New Line on Complete
     if iteration == total: 
         print()
+
+def check_path(path: str, make_dir=False)->list:
+    '''
+    Accepts a path, check if it exists. Creates directory if make_dir = True.
+    Returns a list as follows:
+    [True] - it exists and is a directory
+    [True, 'Directory Created'] - it does not exists but make_dir = True
+    [False, 'File] - it exists but is a file
+    ['False', 'Does not exist'] - if it does not exist and make_dir is false
+    ['False', err] in case there is an error in code
+
+    '''
+    try:
+
+        path_p = Path(path)
+        if path_p.exists():
+            if path_p.is_dir():
+                return [True]
+            else:
+                return [False, 'File']
+        else:
+            if make_dir:
+                path_p.mkdir()
+                return [True, 'Directory Created']
+            else:
+                return [False, 'Does not exist']
+    except Exception as err:
+        return [False, err]
+
+def pdf_page_extractor(source_path: str, dest_path: str, no_of_pages:int, auto_save_output=False)->list:
+    '''
+    accepts path to a folder, extracts number of pages from each pdf file in that folder.
+    Returns list as given below:
+    [True, pdf file] - if all goes fine. pdf file is one consolidated file with given number of pages from each file
+    [False] - if there is an error
+    '''
+    try:
+        check_1, check_2 = False, False
+
+        # convert path to Path object
+        source_path_p=Path(source_path)    
+        dest_path_p=Path(dest_path)
+
+        # check if input exists
+        if check_path(source_path_p):
+            check_1=True
+        else:
+            print('Source path is not a valid directory. Give a valid directory!')
+            return [False]
+
+        if check_path(dest_path_p, make_dir=True):
+            check_2=True
+
+
+        if check_1 and check_2:
+
+            # get list of files in source folder
+            list_of_files = os.listdir(source_path_p)
+
+            # create empty pdf file in memory
+            out_pdf_file = PdfWriter()
+
+            # iterate over files
+            for file in list_of_files:
+                # create full path
+                full_path = source_path_p.joinpath(file)
+                # check if file is pdf
+                if full_path.suffix == '.pdf':
+                    # read file
+                    pdf_file = PdfReader(full_path)
+                    # get total pages
+                    total_pages = len(pdf_file.pages)
+                    if total_pages ==0:
+                        pass
+                    else:
+                        # extract and add pages
+                        for page in range(0,min(no_of_pages, total_pages)):
+                            out_pdf_file.add_page(pdf_file.pages[page])
+                
+            
+            if auto_save_output:
+                # save output pdf in destination directory
+
+                # check if output file has atleast 1 page
+                out_pages = len(out_pdf_file.pages)
+                if out_pages>0:
+                    with open(dest_path_p.joinpath('Output.pdf'), 'wb') as out_stream:
+                        out_pdf_file.write(out_stream)
+                
+            return [True, out_pdf_file]
+            
+    except Exception as err:
+        return [False, err]
+
